@@ -153,7 +153,7 @@ fail(Tag, Reason) ->
 enum([H|_] = List) when is_atom(H); is_binary(H) ->
     fun(Val) ->
 	    Member = if is_binary(H) -> to_binary(Val);
-			is_atom(H) -> to_atom(Val)
+			is_atom(H) -> to_existing_atom(Val)
 		     end,
 	    case lists:member(Member, List) of
 		true -> Member;
@@ -164,7 +164,7 @@ enum([H|_] = List) when is_atom(H); is_binary(H) ->
 -spec bool() -> validator(boolean()).
 bool() ->
     fun(Val) ->
-	    case to_atom(Val) of
+	    case to_existing_atom(Val) of
 		on -> true;
 		off -> false;
 		yes -> true;
@@ -318,7 +318,7 @@ file(write) ->
 			    fail({create_file, Why, Path})
 		    end;
 		{error, Why} ->
-		    fail({create_dir, Why, Path})
+		    fail({create_dir, Why, filename:dirname(Path)})
 	    end
     end.
 
@@ -644,8 +644,7 @@ options(Validators, Options) ->
 format_error(Why, []) ->
     format_error(Why);
 format_error(Why, Ctx) ->
-    [H|T] = format_error(Why),
-    format_ctx(Ctx) ++ ": " ++ [string:to_lower(H)|T].
+    format_ctx(Ctx) ++ ": " ++ format_error(Why).
 
 -spec format_error(error_reason()) -> string().
 format_error({bad_atom, Bad}) ->
@@ -813,7 +812,9 @@ format_yaml_type(Unexpected) ->
 format_yaml(I) when is_integer(I) ->
     integer_to_list(I);
 format_yaml(B) when is_atom(B) ->
-    erlang:atom_to_binary(B, utf8);
+    try erlang:atom_to_binary(B, latin1)
+    catch _:badarg -> erlang:atom_to_binary(B, utf8)
+    end;
 format_yaml(Y) ->
     S = try iolist_to_binary(fast_yaml:encode(Y))
 	catch _:_ ->
@@ -909,7 +910,7 @@ replace_macro(L, Macro, Macros, Path) when is_list(L) ->
 replace_macro({K, V}, Macro, Macros, Path) ->
     {K, replace_macro(V, Macro, Macros, Path)};
 replace_macro(V, {Name, Val}, Macros, Path) ->
-    V1 = if is_atom(V) -> atom_to_binary(V, utf8);
+    V1 = if is_atom(V) -> atom_to_binary(V, latin1);
 	    true -> V
 	 end,
     case V1 of
@@ -956,7 +957,7 @@ read_include_files(Includes, Opts, Paths) ->
 %%%===================================================================
 -spec to_binary(term()) -> binary().
 to_binary(A) when is_atom(A) ->
-    atom_to_binary(A, utf8);
+    atom_to_binary(A, latin1);
 to_binary(B) when is_binary(B) ->
     B;
 to_binary(Bad) ->
@@ -964,7 +965,7 @@ to_binary(Bad) ->
 
 -spec to_atom(term()) -> atom().
 to_atom(B) when is_binary(B) ->
-    try binary_to_atom(B, utf8)
+    try binary_to_atom(B, latin1)
     catch _:system_limit -> fail({bad_length, 255})
     end;
 to_atom(A) when is_atom(A) ->
@@ -972,7 +973,17 @@ to_atom(A) when is_atom(A) ->
 to_atom(Bad) ->
     fail({bad_atom, Bad}).
 
+-spec to_existing_atom(term()) -> atom() | binary().
+to_existing_atom(B) when is_binary(B) ->
+    try binary_to_existing_atom(B, latin1)
+    catch _:_ -> B
+    end;
+to_existing_atom(A) ->
+    to_atom(A).
+
 -spec to_string(term()) -> string().
+to_string(A) when is_atom(A) ->
+    atom_to_list(A);
 to_string(S) ->
     binary_to_list(to_binary(S)).
 
